

class ImitateProducer:
    """ImitateProducer

    ATTRS:
        prop (dict): producer config
    """

    def __init__(self, prop):
        self.prop = prop



    def send(self, message_record):
        """ send a message record

        :param message_record:  (MessageRecord)
        :return: (MessageRecord)
        """
        pass